@@ -1,8 +1,11 @@
 from ._robot_transport_serial import RobotTransportSerial
 from ._serial_tcp_connection import SerialTCPConnection
 from .._comms_constants import CONNECTION_STATUS
+from ..._mm_logging import getLogger
 import threading
 
+logger = getLogger()
+
 
 class RobotTransportTCP(RobotTransportSerial):
     def __init__(self, packetReceivedCallback, connectionStatusCallback):
@@ -16,7 +19,13 @@ class RobotTransportTCP(RobotTransportSerial):
             except Exception as e:
                 pass
         self._connection = SerialTCPConnection(address, port)
-        self._connection.open()
+        try:
+            self._connection.open()
+        except Exception as e:
+            logger.error(
+                "Failed to connect to IP robot - check that it is on and listening"
+            )
+            raise
         # Flushing not needed for a new socket and slows the connection
         # self._connection.flushInput()
         # self._connection.flushOutput()
